@@ -201,7 +201,7 @@ class IssueBoundary:
                 first_space_index = doc_text_without_issue.find(' ')
                 replacement = doc_text_without_issue[0:first_space_index]
                 span.end_char += first_space_index
-                span._.suggestions = [replacement.capitalize()]
+                span._.suggestions = [replacement[0].upper() + replacement[1:]]
 
             # order matters, must come after _would_cause_lowercase_first_letter
             if IssueBoundary._is_comma_replacement_that_could_be_deletion(span):
